import { IVoxaSheet } from "./VoxaSheet";
export declare abstract class Schema {
    intents: IIntent[];
    slots: ISlot[];
    downloads: IDownload[];
    AVAILABLE_LOCALES: string[];
    fileContent: IFileContent[];
    views: IView[];
    invocations: Invocation[];
    publishing: IPublishingInformation[];
    NAMESPACE: string;
    interactionOptions: any;
    constructor(namespace: string | undefined, availableLocales: string[] | undefined, voxaSheets: IVoxaSheet[], interactionOption: any);
    abstract validate(locale: string, environment: string): void;
    abstract build(locale: string, environment: string): void;
    intentsByPlatformAndEnvironments(locale: string, environment: string): IIntent[];
    buildDownloads(): void;
    buildViewsMapping(): void;
    buildViews(): void;
    buildSynonyms(): void;
    mergeManifest(environment: string): any;
    protected filterByPlatform(slot: ISlotDefinition): boolean;
}
export interface IIntent {
    name: string;
    samples: string[];
    slotsDefinition: ISlotDefinition[];
    canFulfillIntent: boolean;
    startIntent: boolean;
    signInRequired: boolean;
    endIntent: boolean;
    events: string[] | IEvent[];
    environments: string[];
    platforms: string[];
    locale: string;
}
export interface IEvent {
    name: string;
}
export interface IFileContent {
    path: string;
    content: any;
}
export interface Invocation {
    locale: string;
    name: string;
    environment: string;
}
export interface ISlotDefinition {
    name: string;
    type: string;
    platform?: string;
}
export interface ISlot {
    locale: string;
    name: string;
    values: ISlotSynonymns[];
}
export interface ISlotSynonymns {
    value: string;
    synonyms: string[];
}
export interface IView {
    locale: string;
    data: {};
}
export interface IDownload {
    name: string;
    data: Array<{}>;
    locale: string;
}
export interface IPublishingInformation {
    key: string;
    value: string | object;
    environments: string[];
}
